@@ -870,7 +870,12 @@ sub getPngLibrary($@) {
 
     my $pnglib;
     {
-        my $default = "libpng" . libSuffix($platform);
+        my $default;
+        if (-d("/usr/link/libpng")) {
+            $default = "/usr/link/libpng/libpng" . libSuffix($platform);
+        } else {
+            $default = "libpng" . libSuffix($platform); 
+        }
 
         print("What is your PNG (graphics format) library?\n");
         
