@@ -508,22 +508,18 @@ main(int argc, char **argv) {
         if (strcmp(argv[arg], "-runtime") == 0)
             runtime = TRUE;
         else {
-            if (strlen(argv[arg]) > 200)
-                error = TRUE;
-            else {
-                const char * options;
-                processOneLibrary(argv[arg], runtime, explicit, 
-                                  &options, &error);
-                if (!error) {
-                    if (strlen(outputLine) + strlen(options) + 1 + 1 > 
-                        sizeof(outputLine))
-                        error = TRUE;
-                    else {
-                        strcat(outputLine, " ");
-                        strcat(outputLine, options);
-                    }
-                    strfree(options);
+            const char * options;
+            processOneLibrary(argv[arg], runtime, explicit, 
+                              &options, &error);
+            if (!error) {
+                if (strlen(outputLine) + strlen(options) + 1 + 1 > 
+                    sizeof(outputLine))
+                    error = TRUE;
+                else {
+                    strcat(outputLine, " ");
+                    strcat(outputLine, options);
                 }
+                strfree(options);
             }
         }
     }
