@@ -541,7 +541,7 @@ alpha_trans(FILE *     const ifp,
             for (col = 0 ; col < cols && !found_transparent_pixel; ++col) {
                 if (alpha_mask[row][col] == 0) {
                     found_transparent_pixel = TRUE;
-                    transcolor = xeltopixel(xelrow[col]);
+                    transcolor = pnm_xeltopixel(xelrow[col], format);
                 }
             }
         }
