@@ -110,6 +110,10 @@ parse_command_line(int argc, char ** argv,
     OPTENT3(0,   "alphaout",   OPT_STRING, 
             &cmdlineP->alpha_filename, &alphaoutSpec,             0);
 
+    opt.opt_table = option_def;
+    opt.short_allowed = TRUE;  /* We have short (old-fashioned) options */
+    opt.allowNegNum = FALSE;  /* We have no parms that are negative numbers */
+
     optParseOptions3(&argc, argv, opt, sizeof(opt), 0);
         /* Uses and sets argc, argv, and all of *cmdlineP. */
 
@@ -143,9 +147,12 @@ parse_command_line(int argc, char ** argv,
 static void 
 read_rle_header(FILE *ifp)
 {
+   int rc;
    int	i;
    hdr.rle_file = ifp;
-   rle_get_setup(&hdr);
+   rc = rle_get_setup(&hdr);
+   if (rc != 0)
+       pm_error("rle_get_setup() failed.  Probably input is not valid RLE");
    width = hdr.xmax - hdr.xmin + 1;
    height = hdr.ymax - hdr.ymin + 1;
    VPRINTF(stderr, "Image size: %dx%d\n", width, height);
