@@ -14,6 +14,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include "pbm.h"
+#include "mallocvar.h"
 
 
 /* readatkraster
@@ -281,8 +282,7 @@ ReadATKRaster(FILE * const file,
     *rwidth = width;
     *rheight = height;
     rowlen = (width + 7) / 8;
-    *destaddrP = (unsigned char *) 
-        malloc (sizeof(unsigned char) * height * rowlen);
+    MALLOCARRAY(*destaddrP, height * rowlen);
     if (destaddrP == NULL)
         pm_error("Unable to allocate %u bytes for the input image.",
                  height * rowlen);
