@@ -568,13 +568,13 @@ clusterConvertRow(struct converter * const converterP,
                   tuple                    bitrow[]) {
 
     struct clusterState * const stateP = converterP->stateP;
-    unsigned int const radius = stateP->radius;
+    unsigned int const diameter = 2 * stateP->radius;
 
     unsigned int col;
 
     for (col = 0; col < converterP->cols; ++col) {
         float const threshold = 
-            stateP->clusterMatrix[row % radius][col % radius];
+            stateP->clusterMatrix[row % diameter][col % diameter];
         bitrow[col][0] = 
             grayrow[col][0] > threshold ? PAM_BW_WHITE : PAM_BLACK;
     }
@@ -586,10 +586,11 @@ static void
 clusterDestroy(struct converter * const converterP) {
 
     struct clusterState * const stateP = converterP->stateP;
+    unsigned int const diameter = 2 * stateP->radius;
 
     unsigned int row;
 
-    for (row = 0; row < stateP->radius; ++row)
+    for (row = 0; row < diameter; ++row)
         free(stateP->clusterMatrix[row]);
 
     free(stateP->clusterMatrix);
@@ -612,6 +613,7 @@ createClusterConverter(struct pam *    const graypamP,
     */
     
     int const clusterNormalizer = radius * radius * 2;
+    unsigned int const diameter = 2 * radius;
 
     struct converter converter;
     struct clusterState * stateP;
@@ -625,13 +627,13 @@ createClusterConverter(struct pam *    const graypamP,
 
     stateP->radius = radius;
 
-    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, radius);
-    for (row = 0; row < radius; ++row) {
+    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, diameter);
+    for (row = 0; row < diameter; ++row) {
         unsigned int col;
 
-        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], radius);
+        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], diameter);
         
-        for (col = 0; col < radius; ++col) {
+        for (col = 0; col < diameter; ++col) {
             switch (ditherType) {
             case DT_REGULAR: 
                 switch (radius) {
