@@ -393,7 +393,12 @@ searchColormapCloseComplex(struct pam * const pamP,
    Same as searchColorMap().  Not as fast as searchColorMapSimple().
 -----------------------------------------------------------------------------*/
     unsigned int i;
-    unsigned int const divider = colormapMaxval < 256 ? 1 : 2;
+    unsigned int const usableDepth = MIN(3, pamP->depth);
+        /* We look at only this many planes, because we might have
+           arithmetic overflow with more.  (Netpbm 10.31 uses a more
+           sophisticated method and can use all the planes)
+        */
+    unsigned int const divider = colormapMaxval < 256 ? 1 : 3;
         /* We divide our sum by this to make sure it fits in a "long" */
     unsigned long dist;
         /* The closest distance we've found so far between the value of
@@ -413,7 +418,7 @@ searchColormapCloseComplex(struct pam * const pamP,
 
         newdist = 0;
 
-        for (plane=0; plane < pamP->depth; ++plane) {
+        for (plane=0; plane < usableDepth; ++plane) {
             sample const normalizedSample = (sample)
                 (tuple[plane] * maxvalNormalizer + 0.5);
             
@@ -723,7 +728,7 @@ main(int argc, char * argv[] ) {
     ifp = pm_openr(cmdline.inputFilespec);
 
     pnm_readpaminit(ifp, &inpam, PAM_STRUCT_SIZE(tuple_type));
-    
+
     {
         FILE * mapfile;
         struct pam mappam;
