@@ -57,6 +57,23 @@ pnm_allocpamrown(const struct pam * const pamP) {
 
 
 
+static bool
+plain(int const format) {
+
+    switch (format) {
+    case PAM_FORMAT:
+    case RPPM_FORMAT:
+    case RPGM_FORMAT:
+    case RPBM_FORMAT:
+        return FALSE;
+        break;
+    default:
+        return TRUE;
+    }
+}
+
+
+
 void 
 pnm_readpamrown(const struct pam * const pamP, 
                 tuplen *           const tuplenrow) {
@@ -88,7 +105,7 @@ pnm_readpamrown(const struct pam * const pamP,
         for (col = 0; col < pamP->width; col++) {
             int samp;
             for (samp = 0; samp < pamP->depth; samp++) {
-                if (pamP->plainformat)
+                if (plain(pamP->format))
                     tuplenrow[col][samp] = 
                         (float)pm_getuint(pamP->file) / pamP->maxval;
                 else 
