@@ -6,10 +6,6 @@
 
 /* Here are some routines internal to the pbm library. */
 
-char pbm_getc ARGS(( FILE* file ));
-unsigned char pbm_getrawbyte ARGS(( FILE* file ));
-int pbm_getint ARGS(( FILE* file ));
-
 void pbm_readpbminitrest ARGS(( FILE* file, int* colsP, int* rowsP ));
 
 #endif /*_LIBPBM_H_*/
